@@ -1,14 +1,15 @@
 import logging
+import typing
 
-from zeep.proxy import ServiceProxy
+from zeep.proxy import AsyncServiceProxy, ServiceProxy
 from zeep.settings import Settings
-from zeep.transports import Transport
+from zeep.transports import AsyncTransport, Transport
 from zeep.wsdl import Document
 
 logger = logging.getLogger(__name__)
 
 
-class Factory(object):
+class Factory:
     def __init__(self, types, kind, namespace):
         self._method = getattr(types, "get_%s" % kind)
 
@@ -34,7 +35,7 @@ class Factory(object):
         return self._method("{%s}%s" % (self._ns, key))
 
 
-class Client(object):
+class Client:
     """The zeep Client.
 
     :param wsdl:
@@ -50,6 +51,8 @@ class Client(object):
 
     """
 
+    _default_transport = Transport
+
     def __init__(
         self,
         wsdl,
@@ -64,7 +67,9 @@ class Client(object):
             raise ValueError("No URL given for the wsdl")
 
         self.settings = settings or Settings()
-        self.transport = transport if transport is not None else Transport()
+        self.transport = (
+            transport if transport is not None else self._default_transport()
+        )
         self.wsdl = Document(wsdl, self.transport, settings=self.settings)
         self.wsse = wsse
         self.plugins = plugins if plugins is not None else []
@@ -98,7 +103,11 @@ class Client(object):
             )
         return self._default_service
 
-    def bind(self, service_name=None, port_name=None):
+    def bind(
+        self,
+        service_name: typing.Optional[str] = None,
+        port_name: typing.Optional[str] = None,
+    ):
         """Create a new ServiceProxy for the given service_name and port_name.
 
         The default ServiceProxy instance (`self.service`) always referes to
@@ -170,9 +179,7 @@ class Client(object):
         return self.wsdl.types.get_element(name)
 
     def set_ns_prefix(self, prefix, namespace):
-        """Set a shortcut for the given namespace.
-
-        """
+        """Set a shortcut for the given namespace."""
         self.wsdl.types.set_ns_prefix(prefix, namespace)
 
     def set_default_soapheaders(self, headers):
@@ -195,7 +202,7 @@ class Client(object):
             port = list(service.ports.values())[0]
         return port
 
-    def _get_service(self, name):
+    def _get_service(self, name: typing.Optional[str]) -> str:
         if name:
             service = self.wsdl.services.get(name)
             if not service:
@@ -205,6 +212,32 @@ class Client(object):
         return service
 
 
+class AsyncClient(Client):
+    _default_transport = AsyncTransport
+
+    def bind(
+        self,
+        service_name: typing.Optional[str] = None,
+        port_name: typing.Optional[str] = None,
+    ):
+        """Create a new ServiceProxy for the given service_name and port_name.
+
+        The default ServiceProxy instance (`self.service`) always referes to
+        the first service/port in the wsdl Document.  Use this when a specific
+        port is required.
+
+        """
+        if not self.wsdl.services:
+            return
+
+        service = self._get_service(service_name)
+        port = self._get_port(service, port_name)
+        return AsyncServiceProxy(self, port.binding, **port.binding_options)
+
+    async def __aexit__(self, exc_type=None, exc_value=None, traceback=None) -> None:
+        await self.transport.close()
+
+
 class CachingClient(Client):
     """Shortcut to create a caching client, for the lazy people.
 
@@ -220,4 +253,4 @@ class CachingClient(Client):
 
         kwargs["transport"] = kwargs.get("transport") or Transport(cache=SqliteCache())
 
-        super(CachingClient, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
